@@ -42,12 +42,10 @@ class BucketsApi(object):
             rules.append(retention_rules)
 
         if bucket is None:
-
-            bucket = PostBucketRequest(name=bucket_name, retention_rules=rules, description=description)
-
-            if org_id is None:
-                org_id = self._influxdb_client.org
-            bucket.org_id = org_id
+            bucket = PostBucketRequest(name=bucket_name,
+                                       retention_rules=rules,
+                                       description=description,
+                                       org_id=self._influxdb_client.org if org_id is None else org_id)
 
         return self._buckets_service.post_buckets(post_bucket_request=bucket)
 
@@ -87,6 +85,16 @@ class BucketsApi(object):
         else:
             return None
 
-    def find_buckets(self):
-        """Get all buckets."""
-        return self._buckets_service.get_buckets()
+    def find_buckets(self, **kwargs):
+        """List buckets.
+
+        :key int offset: Offset for pagination
+        :key int limit: Limit for pagination
+        :key str after: The last resource ID from which to seek from (but not including).
+                        This is to be used instead of `offset`.
+        :key str org: The organization name.
+        :key str org_id: The organization ID.
+        :key str name: Only returns buckets with a specific name.
+        :return: Buckets
+        """
+        return self._buckets_service.get_buckets(**kwargs)
